summaryrefslogtreecommitdiffstatshomepage
path: root/src/osd
diff options
context:
space:
mode:
author arbee <rb6502@users.noreply.github.com>2024-02-13 22:47:29 -0500
committer arbee <rb6502@users.noreply.github.com>2024-02-13 22:47:29 -0500
commitf8345b810deb0bd1c10c9b5fa01667187d2c726e (patch)
treebd7200ad325a80a6907ffe59fc16d48c29129a36 /src/osd
parent45890ad85c648fecd28c915cc9934b8afa0cb1cc (diff)
Fixed OSD interaction with updated default keys. [R. Belmont]
Diffstat (limited to 'src/osd')
-rw-r--r--src/osd/modules/input/input_windows.cpp5
-rw-r--r--src/osd/sdl/osdsdl.cpp15
2 files changed, 15 insertions, 5 deletions
diff --git a/src/osd/modules/input/input_windows.cpp b/src/osd/modules/input/input_windows.cpp
index 1db0e3ac02c..f3ef38bcab0 100644
--- a/src/osd/modules/input/input_windows.cpp
+++ b/src/osd/modules/input/input_windows.cpp
@@ -131,6 +131,11 @@ void windows_osd_interface::customize_input_type_list(std::vector<input_type_ent
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F12, KEYCODE_LSHIFT, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LALT);
break;
+ // add a Not lctrl Not lalt condition to the pause key
+ case IPT_UI_PAUSE:
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F5, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LALT);
+ break;
+
// lctrl-lalt-F5 to toggle post-processing
case IPT_OSD_4:
entry.configure_osd("POST_PROCESS", N_p("input-name", "Toggle Post-Processing"));
diff --git a/src/osd/sdl/osdsdl.cpp b/src/osd/sdl/osdsdl.cpp
index 6c5aef9f08c..89a7fa7154d 100644
--- a/src/osd/sdl/osdsdl.cpp
+++ b/src/osd/sdl/osdsdl.cpp
@@ -348,12 +348,12 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
// various dipswitches, and pressing them together with
// LCTRL will still press/toggle these dipswitches.
- // add a Not lcrtl condition to the reset key
+ // add a Not lctrl condition to the reset key
case IPT_UI_SOFT_RESET:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F3, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LSHIFT);
break;
- // add a Not lcrtl condition to the show gfx key
+ // add a Not lctrl condition to the show gfx key
case IPT_UI_SHOW_GFX:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F4, input_seq::not_code, KEYCODE_LCONTROL);
break;
@@ -370,7 +370,7 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F6, KEYCODE_LCONTROL);
break;
- // add a Not lcrtl condition to the toggle cheat key
+ // add a Not lctrl condition to the toggle cheat key
case IPT_UI_TOGGLE_CHEAT:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F6, input_seq::not_code, KEYCODE_LCONTROL);
break;
@@ -387,12 +387,17 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F12, KEYCODE_LSHIFT, KEYCODE_LALT);
break;
- // add a Not lcrtl condition to the load state key
+ // add a Not lctrl condition to the pause key
+ case IPT_UI_PAUSE:
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F5, input_seq::not_code, KEYCODE_LCONTROL);
+ break;
+
+ // add a Not lctrl Not lshift condition to the load state key
case IPT_UI_LOAD_STATE:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F7, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LSHIFT);
break;
- // add a Not lcrtl condition to the throttle key
+ // add a Not lctrl condition to the throttle key
case IPT_UI_THROTTLE:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F10, input_seq::not_code, KEYCODE_LCONTROL);
break;